# Electric aircraft battery charging infrastructure optimization

Code Author: Simon van Oosterom

Operations and Environment Group, Faculty of Aerospace Engineering, Delft University of Technology 

Corresponding author: Jacco Hoekstra

Contact Information: j.m.hoekstra@tudelft.nl



Delft University of Technology - Faculty of Aerospace Engineering

P.O. Box 5058

2600 GB Delft

The Netherlands




## General Introduction

This repository contains the code developed for determining the optimal size of charging infrastructure for a network of airports, to service a fleet of electric aircraft operating with a battery swapping system.
It is being made public both to act as supplementary data for publications and the PhD thesis of Simon van Oosterom, and in order for other researchers to use this repository in their own work. 

## Research Overview

### Data processing

The repository uses flight data from the [FlightRadar24](https://www.flightradar24.com/), which is publicly available. Data from the desired aircraft can be copied.

This repository can be used to process the retrieved data. This is done by the ``Read_flight_Schedule`` function from ``E_AC_Infra_Background_Functions.py`` file. In this file, several functions can be found to graph the data:

- ``Plot_Flights`` graphs the processed flights onto a map
- ``PlotMostPopAps`` creates a bar plot with the number of flights per airport 
- ``PlotInOutHist`` creates a histogram of the number of flights 

### Charging infrastructure optimization 

The historical flight data is used to optimize the required infrastructure for recharging batteries to service these flights. This is performed in the ``E_AC_Infra_Optimizer.py`` file. In this file

- The model parameters are specified
- The flight data is loaded
- Infrastructure is optimized using a variable large neighborhood search. The cost of the infrastructure is given by the investment costs and the operational costs (electricity + delays caused).

This file is also used to compare the three infrastructure optimization methods:
- Infrastructure optimized for the peak-day of operations
- Infrastructure optimized for a median-day of operations
- Infrastructure optimized for a balance of the different days of operations.


## Dependencies

Apart from the standard packages (numpy etc.), the following are required:

- GurobiPy


## Dissimination
The work performed in this repository has been described in the following publications:

S. van Oosterom and M. Mitici. “Optimizing the battery charging and swapping infrastructure for electric short-haul aircraft - The case of electric flight in Norway”. English. In: Transportation Research Part C: Emerging Technologies 155 (2023). ISSN:0968-090X. [DOI:10.1016/j.trc.2023.104313](DOI:10.1016/j.trc.2023.104313)